@@ -161,7 +161,8 @@ def preprocessing_training(df, industry_dictionary, state_dictionary,
 
     df_leads_clean = utils.convert_date(df=df_leads_clean)
     # Prepare target column
-    df_leads_clean = devutils.set_target_column(df=df_leads_clean,model_type=model_type)
+    multiplier=config['BV_multiplier']
+    df_leads_clean = devutils.set_target_column(df=df_leads_clean,model_type=model_type,multiplier=multiplier)
 
     nna = df_leads_clean.isna().sum()
     logging.info( f"NA in final dataframe:" )
